"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
require("mocha"); // tslint:disable-line:no-import-side-effect
var assert = require("power-assert");
var testEntity_1 = require("../../tests/utils/testEntity");
var Cursor_1 = require("../../types/Cursor");
var PaginationDirection_1 = require("../../types/PaginationDirection");
var SortOrder_1 = require("../../types/SortOrder");
var index_1 = require("./index");
describe('createGetEntitiesResult backward', function () {
    var sort = { id: SortOrder_1.asc };
    var firstId = 'test_id_1';
    var secondId = 'test_id_2';
    var firstEntity = __assign({}, testEntity_1.testEntity, { id: firstId });
    var secondEntity = __assign({}, testEntity_1.testEntity, { id: secondId });
    var firstCursor = 'eyJpZCI6InRlc3RfaWRfMSJ9';
    var secondCursor = 'eyJpZCI6InRlc3RfaWRfMiJ9';
    it('should return the correct result when there are no entities', function () {
        var entities = [];
        var pagination = { cursor: Cursor_1.start, direction: PaginationDirection_1.backward, limit: 1 };
        var isEnd = true;
        var result = index_1.default({ entities: entities, isEnd: isEnd, pagination: pagination, sort: sort });
        assert.deepEqual(result, {
            backwardCursor: Cursor_1.start,
            entities: entities,
            forwardCursor: Cursor_1.start,
            hasMoreBackward: false,
            hasMoreForward: false,
        });
    });
    it('should return the correct result when not at the end going from start', function () {
        var entities = [firstEntity, secondEntity];
        var pagination = { cursor: Cursor_1.start, direction: PaginationDirection_1.backward, limit: 1 };
        var isEnd = false;
        var result = index_1.default({ entities: entities, isEnd: isEnd, pagination: pagination, sort: sort });
        assert.deepEqual(result, {
            backwardCursor: firstCursor,
            entities: entities,
            forwardCursor: secondCursor,
            hasMoreBackward: true,
            hasMoreForward: false,
        });
    });
    it('should return the correct result when at the end going from start', function () {
        var entities = [firstEntity, secondEntity];
        var pagination = { cursor: Cursor_1.start, direction: PaginationDirection_1.backward, limit: 1 };
        var isEnd = true;
        var result = index_1.default({ entities: entities, isEnd: isEnd, pagination: pagination, sort: sort });
        assert.deepEqual(result, {
            backwardCursor: firstCursor,
            entities: entities,
            forwardCursor: secondCursor,
            hasMoreBackward: false,
            hasMoreForward: false,
        });
    });
    it('should return the correct result when not at the end going from cursor', function () {
        var entities = [secondEntity];
        var pagination = { cursor: firstCursor, direction: PaginationDirection_1.backward, limit: 1 };
        var isEnd = false;
        var result = index_1.default({ entities: entities, isEnd: isEnd, pagination: pagination, sort: sort });
        assert.deepEqual(result, {
            backwardCursor: secondCursor,
            entities: entities,
            forwardCursor: secondCursor,
            hasMoreBackward: true,
            hasMoreForward: true,
        });
    });
    it('should return the correct result when at the end going from cursor', function () {
        var entities = [secondEntity];
        var pagination = { cursor: firstCursor, direction: PaginationDirection_1.backward, limit: 1 };
        var isEnd = true;
        var result = index_1.default({ entities: entities, isEnd: isEnd, pagination: pagination, sort: sort });
        assert.deepEqual(result, {
            backwardCursor: secondCursor,
            entities: entities,
            forwardCursor: secondCursor,
            hasMoreBackward: false,
            hasMoreForward: true,
        });
    });
});
//# sourceMappingURL=backward.test.js.map