"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("mocha"); // tslint:disable-line:no-import-side-effect
var assert = require("power-assert");
var testEntity_1 = require("../../tests/utils/testEntity");
var Cursor_1 = require("../../types/Cursor");
var PaginationDirection_1 = require("../../types/PaginationDirection");
var SortOrder_1 = require("../../types/SortOrder");
var createCursorFromEntity_1 = require("../createCursorFromEntity");
var index_1 = require("./index");
describe('createCursorFromEntity', function () {
    var sort = { id: SortOrder_1.asc, numberProp: SortOrder_1.desc };
    it('should return empty filter when the cursor is start', function () {
        var pagination = { cursor: Cursor_1.start, direction: PaginationDirection_1.forward, limit: 1 };
        var actualResult = index_1.default(pagination, sort);
        var expectedResult = {};
        assert.deepEqual(actualResult, expectedResult);
    });
    it('should return the correct filter when the cursor is defined and going forward', function () {
        var cursor = createCursorFromEntity_1.default(testEntity_1.testEntity, sort);
        var pagination = { cursor: cursor, direction: PaginationDirection_1.forward, limit: 1 };
        var actualResult = index_1.default(pagination, sort);
        var expectedResult = {
            id: { $gt: testEntity_1.testEntity.id },
            numberProp: { $lte: testEntity_1.testEntity.numberProp },
        };
        assert.deepEqual(actualResult, expectedResult);
    });
    it('should return the correct filter when the cursor is defined and going backward', function () {
        var cursor = createCursorFromEntity_1.default(testEntity_1.testEntity, sort);
        var pagination = { cursor: cursor, direction: PaginationDirection_1.backward, limit: 1 };
        var actualResult = index_1.default(pagination, sort);
        var expectedResult = {
            id: { $lt: testEntity_1.testEntity.id },
            numberProp: { $gte: testEntity_1.testEntity.numberProp },
        };
        assert.deepEqual(actualResult, expectedResult);
    });
});
//# sourceMappingURL=index.test.js.map